/* OSD */

$osd_levelbar_height:8px;

.osd-window {
  @extend %osd_panel;
  text-align: center;
  font-weight: bold;
  spacing: $base_spacing * 2; // 12px
  margin: $base_margin * 8; // 32px
  min-width: 64px;
  min-height: 64px;

  StIcon {
    icon-size:$base_icon_size * 6;
  }

  .osd-monitor-label { font-size: 3em; }
  
  .level {
    height: $osd_levelbar_height;
    -barlevel-height: $osd_levelbar_height;
    -barlevel-background-color: transparentize($osd_fg_color, if($variant=='light', 0.7, 0.9));
    -barlevel-active-background-color: $osd_fg_color;
    -barlevel-overdrive-color: $destructive_color;
    -barlevel-overdrive-separator-width: 3px;
  }
}

/* Pad OSD */
.pad-osd-window {
  padding: 32px;
  background-color: transparentize(#000, 0.2);

  .pad-osd-title-box { spacing: 12px; }
  .pad-osd-title-menu-box { spacing: 6px; }
}

.combo-box-label {
  width: 15em;
}

.resize-popup {
  @extend %osd_panel;
}