.panel-workspace-indicator {
	padding: 0 8px;
}

.panel-workspace-indicator-box {
	padding: 2px 0;
}

.panel-workspace-indicator-box .workspace {
	width: 40px;
}

.panel-workspace-indicator,
.panel-workspace-indicator-box .workspace {
	border: 1px solid #cccccc;
}

.panel-workspace-indicator,
.panel-workspace-indicator-box .workspace.active {
	background-color: rgba(200, 200, 200, .5);
}

.panel-workspace-indicator-box .workspace {
    background-color: rgba(200, 200, 200, .3);
    border-left-width: 0;
}

.panel-workspace-indicator-box .workspace:first-child {
    border-left-width: 1px;
}

.workspace-indicator-window-preview {
    background-color: #252525;
    border: 1px solid #ccc;
}

.workspace-indicator-window-preview.active {
    background-color: #353535;
    border: 2px solid #ccc;
}
