/* Login Dialog */

.login-dialog-banner-view {
  padding-top: 24px;
  max-width: 23em;
}

.login-dialog {
  //reset
  border: none;
  background-color: transparent;

  $_gdm_bg: lighten(#2e3436, 19%);

  StEntry {
    @if $variant=='dark' {
      $_gdm_entry_bg: transparentize(lighten(desaturate(#241f31, 20%), 2%), 0.5);
      background-color: $_gdm_entry_bg;
      color: $osd_fg_color;
    }
  }

  .modal-dialog-button-box { spacing: 3px; }
  .modal-dialog-button {
    padding: 4px 18px;
    box-shadow: 0 1px 3px rgba(0,0,0,0.2);
    background-color: $_gdm_bg;
    border-color: $_gdm_bg;
    color: $fg_color;

    $_hover_c: lighten($_gdm_bg, 5%);
    &:hover, &:focus {
      background-color: $_hover_c;
      border-color: $_hover_c;
    }
    &:active {
      $_active_c: darken($_gdm_bg, 5%);
      box-shadow: none;
      background-color: $_active_c;
      border-color: $_active_c;
    }
    &:insensitive {
      @include button(insensitive);
      border-color: darken($_gdm_bg, 5%);
      background-color: darken($_gdm_bg, 5%);
      color: transparentize($fg_color, 0.3);
    }
    &:default {
      @include button(normal, $c:$selected_bg_color, $tc:$selected_fg_color);
      border-color: $selected_bg_color;
      &:hover, &:focus { 
        @include button(hover,$c:$selected_bg_color, $tc:$selected_fg_color);
        $_def_hover_c: lighten($selected_bg_color, 5%);
        background-color: $_def_hover_c;
        border-color: $_def_hover_c;
      }
      &:active {
        @include button(active,$c:$selected_bg_color, $tc:$selected_fg_color);
        $_def_active_c: darken($selected_bg_color, 5%);
        background-color: $_def_active_c;
        border-color: $_def_active_c;
      }
      &:insensitive {
        @include button(insensitive);
        border-color: darken($selected_bg_color, 10%);
        background-color: darken($selected_bg_color, 10%);
        color: transparentize($selected_fg_color, 0.3);
      }
    }
  }

  .cancel-button,
  .switch-user-button,
  .login-dialog-session-list-button {
    padding: 0;
    border-radius: 99px;
    width: $base_icon_size * 2;
    height: $base_icon_size * 2;
    border-color: transparentize($bg_color,0.7);
    background-color: transparentize($bg_color,0.7);

    StIcon { icon-size: $base_icon_size; }
  }

  .caps-lock-warning-label,
  .login-dialog-message-warning {
    color: $osd_fg_color;
  }
}

.login-dialog-logo-bin { padding: 24px 0px; }
.login-dialog-banner { color: darken($osd_fg_color,10%); }
.login-dialog-button-box { width: 23em; spacing: 5px; }
.login-dialog-message { text-align: center; }
.login-dialog-message-hint { padding-top: 0; padding-bottom: 20px; }
.login-dialog-user-selection-box { padding: 100px 0px; }
.login-dialog-not-listed-label {
  padding-left: 2px;
  .login-dialog-not-listed-button:focus &,
  .login-dialog-not-listed-button:hover & {
    color: $osd_fg_color;
  }
}

.login-dialog-not-listed-label {
  @include fontsize($base_font_size - 1);
  font-weight: bold;
  color: darken($osd_fg_color,30%);
  padding-top: 1em;
}

.login-dialog-user-list-view { -st-vfade-offset: 1em; }
.login-dialog-user-list {
  spacing: 12px;
  width: 23em;
  &:expanded .login-dialog-user-list-item:selected { background-color: $selected_bg_color; color: $selected_fg_color; }
  &:expanded .login-dialog-user-list-item:logged-in { border-right: 2px solid $selected_bg_color; }
}

.login-dialog-user-list-item {
  border-radius: $base_border_radius + 4px;
  padding: 6px;
  color: darken($osd_fg_color,30%);
  &:ltr .user-widget { padding-right: 1em; }
  &:rtl .user-widget { padding-left: 1em; }
  .login-dialog-timed-login-indicator {
    height: 2px;
    margin-top: 6px;
    background-color: $osd_fg_color;
  }
  &:focus .login-dialog-timed-login-indicator { background-color: $selected_fg_color; }
}

.user-widget-label {
  color: $osd_fg_color;
}

.user-widget.horizontal .user-widget-label {
  @include fontsize($base_font_size + 2);
  font-weight: bold;
  text-align: left;
  padding-left: 15px;

  &:ltr { padding-left: 14px; }
  &:rtl { padding-right: 14px; }
}

.user-widget.vertical .user-widget-label {
  @include fontsize($base_font_size + 5);
  text-align: center;
  font-weight: normal;
  padding-top: 16px;
}

.login-dialog-prompt-layout {
  padding-top: 24px;
  padding-bottom: 12px;
  spacing: $base_spacing * 2;
  width: 23em;
}

.login-dialog-prompt-entry {
  height: 1.5em;
}

.login-dialog-prompt-label {
  color: darken($osd_fg_color, 20%);
  @include fontsize($base_font_size + 1);
  padding-top: 1em;
}
